@@ -52,8 +52,8 @@ def load_lammpstrj(filename, top=None, stride=None, atom_indices=None,
 
     Parameters
     ----------
-    filename : str
-        String filename of LAMMPS trajectory file.
+    filename : path-like
+        Path of LAMMPS trajectory file.
     top : {str, Trajectory, Topology}
         The lammpstrj format does not contain topology information. Pass in
         either the path to a pdb file, a trajectory, or a topology to supply
@@ -89,8 +89,8 @@ def load_lammpstrj(filename, top=None, stride=None, atom_indices=None,
     # informative error message.
     if top is None:
         raise ValueError('"top" argument is required for load_lammpstrj')
-    if not isinstance(filename, string_types):
-        raise TypeError('filename must be of type string for load_lammpstrj. '
+    if not isinstance(filename, (string_types, os.PathLike)):
+        raise TypeError('filename must be of type path-like for load_lammpstrj. '
                         'you supplied %s'.format(type(filename)))
 
     topology = _parse_topology(top)
@@ -120,7 +120,7 @@ class LAMMPSTrajectoryFile(object):
 
     Parameters
     ----------
-    filename : str
+    filename : path-like
         The filename to open. A path to a file on disk.
     mode : {'r', 'w'}
         The mode in which to open the file, either 'r' for read or 'w' for
