@@ -59,7 +59,7 @@ def load_netcdf(filename, top=None, stride=None, atom_indices=None, frame=None):
 
     Parameters
     ----------
-    filename : str
+    filename : path-like
         filename of AMBER NetCDF file.
     top : {str, Trajectory, Topology}
         The NetCDF format does not contain topology information. Pass in either
@@ -113,7 +113,7 @@ class NetCDFTrajectoryFile(object):
 
     Parameters
     ----------
-    filename : str
+    filename : path-like
         The name of the file to open
     mode : {'r', 'w'}, default='r'
         The mode in which to open the file. Valid options are 'r' and 'w' for
