@@ -49,7 +49,7 @@ from datetime import date
 import gzip
 import numpy as np
 import xml.etree.ElementTree as etree
-from copy import copy
+from copy import copy, deepcopy
 from mdtraj.formats.pdb.pdbstructure import PdbStructure
 from mdtraj.core.topology import Topology
 from mdtraj.utils import ilen, cast_indices, in_units_of, open_maybe_zipped
@@ -94,12 +94,12 @@ def _is_url(url):
 @FormatRegistry.register_loader('.pdb')
 @FormatRegistry.register_loader('.pdb.gz')
 def load_pdb(filename, stride=None, atom_indices=None, frame=None,
-             no_boxchk=False, standard_names=True ):
+             no_boxchk=False, standard_names=True, top=None):
     """Load a RCSB Protein Data Bank file from disk.
 
     Parameters
     ----------
-    filename : str
+    filename : path-like
         Path to the PDB file on disk. The string could be a URL. Valid URL
         schemes include http and ftp.
     stride : int, default=None
@@ -125,6 +125,9 @@ def load_pdb(filename, stride=None, atom_indices=None, frame=None,
     standard_names : bool, default=True
         If True, non-standard atomnames and residuenames are standardized to conform
         with the current PDB format version. If set to false, this step is skipped.
+    top : mdtraj.core.Topology, default=None
+        if you give a topology as input the topology won't be parsed from the pdb file
+        it saves time if you have to parse a big number of files
 
     Returns
     -------
@@ -143,14 +146,13 @@ def load_pdb(filename, stride=None, atom_indices=None, frame=None,
     mdtraj.PDBTrajectoryFile : Low level interface to PDB files
     """
     from mdtraj import Trajectory
-    if not isinstance(filename, six.string_types):
-        raise TypeError('filename must be of type string for load_pdb. '
+    if not isinstance(filename, (six.string_types, os.PathLike)):
+        raise TypeError('filename must be of type string or path-like for load_pdb. '
             'you supplied %s' % type(filename))
 
     atom_indices = cast_indices(atom_indices)
 
-    filename = str(filename)
-    with PDBTrajectoryFile(filename, standard_names=standard_names) as f:
+    with PDBTrajectoryFile(filename, standard_names=standard_names, top=top) as f:
         atom_slice = slice(None) if atom_indices is None else atom_indices
         if frame is not None:
             coords = f.positions[[frame], atom_slice, :]
@@ -161,6 +163,8 @@ def load_pdb(filename, stride=None, atom_indices=None, frame=None,
 
         topology = f.topology
         if atom_indices is not None:
+            # The input topology shouldn't be modified because
+            # subset makes a copy inside the function
             topology = topology.subset(atom_indices)
 
         if f.unitcell_angles is not None and f.unitcell_lengths is not None:
@@ -207,7 +211,7 @@ class PDBTrajectoryFile(object):
 
     Parameters
     ----------
-    filename : str
+    filename : path-like
         The filename to open. A path to a file on disk.
     mode : {'r', 'w'}
         The mode in which to open the file, either 'r' for read or 'w' for write.
@@ -217,6 +221,9 @@ class PDBTrajectoryFile(object):
     standard_names : bool, default=True
         If True, non-standard atomnames and residuenames are standardized to conform
         with the current PDB format version. If set to false, this step is skipped.
+    top : mdtraj.core.Topology, default=None
+        if you give a topology as input the topology won't be parsed from the pdb file
+        it saves time if you have to parse a big number of files
 
     Attributes
     ----------
@@ -241,10 +248,10 @@ class PDBTrajectoryFile(object):
     _atomNameReplacements = {}
     _chain_names = [chr(ord('A') + i) for i in range(26)]
 
-    def __init__(self, filename, mode='r', force_overwrite=True, standard_names=True):
+    def __init__(self, filename, mode='r', force_overwrite=True, standard_names=True, top=None):
         self._open = False
         self._file = None
-        self._topology = None
+        self._topology = top
         self._positions = None
         self._mode = mode
         self._last_topology = None
@@ -344,7 +351,9 @@ class PDBTrajectoryFile(object):
                         symbol = atom.element.symbol
                     else:
                         symbol = ' '
-                    if atom.serial is not None:
+                    if atom.serial is not None and len(topology._chains) < 2:
+                        # We can't do this for more than 1 chain
+                        # to prevent issue 1611
                         atomSerial = atom.serial
                     else:
                         atomSerial = atomIndex
@@ -511,33 +520,8 @@ class PDBTrajectoryFile(object):
         if not self._mode == 'r':
             raise ValueError('file not opened for reading')
 
-        self._topology = Topology()
-
         pdb = PdbStructure(self._file, load_all_models=True)
 
-        atomByNumber = {}
-        for chain in pdb.iter_chains():
-            c = self._topology.add_chain()
-            for residue in chain.iter_residues():
-                resName = residue.get_name()
-                if resName in PDBTrajectoryFile._residueNameReplacements and self._standard_names:
-                    resName = PDBTrajectoryFile._residueNameReplacements[resName]
-                r = self._topology.add_residue(resName, c, residue.number, residue.segment_id)
-                if resName in PDBTrajectoryFile._atomNameReplacements and self._standard_names:
-                    atomReplacements = PDBTrajectoryFile._atomNameReplacements[resName]
-                else:
-                    atomReplacements = {}
-                for atom in residue.atoms:
-                    atomName = atom.get_name()
-                    if atomName in atomReplacements:
-                        atomName = atomReplacements[atomName]
-                    atomName = atomName.strip()
-                    element = atom.element
-                    if element is None:
-                        element = PDBTrajectoryFile._guess_element(atomName, residue.name, len(residue))
-
-                    newAtom = self._topology.add_atom(atomName, element, r, serial=atom.serial_number)
-                    atomByNumber[atom.serial_number] = newAtom
 
         # load all of the positions (from every model)
         _positions = []
@@ -557,23 +541,54 @@ class PDBTrajectoryFile(object):
         ## The atom positions read from the PDB file
         self._unitcell_lengths = pdb.get_unit_cell_lengths()
         self._unitcell_angles = pdb.get_unit_cell_angles()
-        self._topology.create_standard_bonds()
-        self._topology.create_disulfide_bonds(self.positions[0])
 
-        # Add bonds based on CONECT records.
-        connectBonds = []
-        for connect in pdb.models[-1].connects:
-            i = connect[0]
-            for j in connect[1:]:
-                if i in atomByNumber and j in atomByNumber:
-                    connectBonds.append((atomByNumber[i], atomByNumber[j]))
-        if len(connectBonds) > 0:
-            # Only add bonds that don't already exist.
-            existingBonds = set(self._topology.bonds)
-            for bond in connectBonds:
-                if bond not in existingBonds and (bond[1], bond[0]) not in existingBonds:
-                    self._topology.add_bond(bond[0], bond[1])
-                    existingBonds.add(bond)
+
+        # Load the topology if None is given
+        if self._topology is None:
+            self._topology = Topology()
+
+            atomByNumber = {}
+            for chain in pdb.iter_chains():
+                c = self._topology.add_chain()
+                for residue in chain.iter_residues():
+                    resName = residue.get_name()
+                    if resName in PDBTrajectoryFile._residueNameReplacements and self._standard_names:
+                        resName = PDBTrajectoryFile._residueNameReplacements[resName]
+                    r = self._topology.add_residue(resName, c, residue.number, residue.segment_id)
+                    if resName in PDBTrajectoryFile._atomNameReplacements and self._standard_names:
+                        atomReplacements = PDBTrajectoryFile._atomNameReplacements[resName]
+                    else:
+                        atomReplacements = {}
+                    for atom in residue.atoms:
+                        atomName = atom.get_name()
+                        if atomName in atomReplacements:
+                            atomName = atomReplacements[atomName]
+                        atomName = atomName.strip()
+                        element = atom.element
+                        if element is None:
+                            element = PDBTrajectoryFile._guess_element(atomName, residue.name, len(residue))
+
+                        newAtom = self._topology.add_atom(atomName, element, r, serial=atom.serial_number)
+                        atomByNumber[atom.serial_number] = newAtom
+
+        
+            self._topology.create_standard_bonds()
+            self._topology.create_disulfide_bonds(self.positions[0])
+
+            # Add bonds based on CONECT records.
+            connectBonds = []
+            for connect in pdb.models[-1].connects:
+                i = connect[0]
+                for j in connect[1:]:
+                    if i in atomByNumber and j in atomByNumber:
+                        connectBonds.append((atomByNumber[i], atomByNumber[j]))
+            if len(connectBonds) > 0:
+                # Only add bonds that don't already exist.
+                existingBonds = set(self._topology.bonds)
+                for bond in connectBonds:
+                    if bond not in existingBonds and (bond[1], bond[0]) not in existingBonds:
+                        self._topology.add_bond(bond[0], bond[1])
+                        existingBonds.add(bond)
 
     @staticmethod
     def _loadNameReplacementTables():
