@@ -22,12 +22,14 @@
 
 import sys
 import functools
+from pathlib import Path
 from mdtraj.testing import eq
 import numpy as np
 import mdtraj as md
 import mdtraj.utils
 from mdtraj.utils import six
 from mdtraj.core import element
+import mdtraj.core.trajectory
 import pytest
 import mdtraj.formats
 from collections import namedtuple
@@ -184,6 +186,23 @@ def precision2(fext1, fext2):
     return min(precision(fext1), precision(fext2))
 
 
+def test_read_path(ref_traj, get_fn):
+    top = get_fn('native.pdb')
+    t = md.load(Path(get_fn(ref_traj.fn)), top=top)
+
+
+def test_write_path(write_traj, get_fn):
+    if write_traj.fext in ('ncrst', 'rst7'):
+        pytest.skip("{} can only store 1 frame per file".format(write_traj.fext))
+    if write_traj.fext in ('mdcrd'):
+        pytest.skip("{} can only store rectilinear boxes".format(write_traj.fext))
+    t = md.load(get_fn('traj.h5'))
+    if t.unitcell_vectors is None:
+        if write_traj.fext in ('dtr', 'lammpstrj'):
+            pytest.skip("{} needs to write unitcells".format(write_traj.fext))
+    t.save(Path(write_traj.fn))
+
+
 def test_read_write(ref_traj, write_traj, get_fn):
     if write_traj.fext in ('ncrst', 'rst7'):
         pytest.skip("{} can only store 1 frame per file".format(write_traj.fext))
@@ -627,7 +646,13 @@ def test_length(get_fn):
 
     for file in files:
         opened = md.open(get_fn(file))
-        loaded = md.load(get_fn(file), top=get_fn('native.pdb'))
+
+        if '.' + file.rsplit('.', 1)[-1] in mdtraj.core.trajectory._TOPOLOGY_EXTS:
+            top = file
+        else:
+            top = 'native.pdb'
+
+        loaded = md.load(get_fn(file), top=get_fn(top))
         assert len(opened) == len(loaded)
 
 
